/* USMID @(#)include/mntent.h	90.2	02/23/96 14:59:51 */

/* COPYRIGHT CRAY RESEARCH, INC. 
 * UNPUBLISHED -- ALL RIGHTS RESERVED UNDER 
 * THE COPYRIGHT LAWS OF THE UNITED STATES */

#ifndef _MNTENT_H
#define _MNTENT_H

/*
 * File system table, see mntent (5)
 *
 * Used by mount(1m)
 */

#define	FSTAB		"/etc/fstab"	/* fstab name */
#define KMTAB		NULL		/* info from the kernel mount table */

#define KMNT_FD		(FILE *)1	/* file descriptor in case of access */
					/* from the kernel mount table */

#define	MNTMAXSTR	256

#define FSFLAG          1		/* file system name flag */
#define DIRFLAG         2		/* directory flag */
#define TYPEFLAG        3		/* type of file system flag */
#define OPTFLAG         4		/* option flag */

#define NOUP            0		/* do not change a linked list */
#define UPD             1		/* update a list to current node */
#define UPREC           2		/* update a list to node previous to */
					/* the current one */

#ifdef _CRAY2
#define	MNTTYPE_NC2	"NC2FS"		/* Cray-2 file system */
#define MNTTYPE_HOST	MNTTYPE_NC2	/* For compatability */
#else
#define	MNTTYPE_NC1	"NC1FS"		/* X/Y-MP file system */
#define MNTTYPE_HOST	MNTTYPE_NC1	/* For compatability */
#endif
#define	MNTTYPE_SFS	"SFS"		/* X/Y-MP shared file system */
#define	MNTTYPE_DFS	"DFS"		/* network file system version 2 */
#define	MNTTYPE_NFS	"NFS"		/* network file system version 2 */
#define	MNTTYPE_NFS3	"NFS3"		/* network file system version 3 */
#define	MNTTYPE_SL	"SLFS"		/* for superlink */
#define	MNTTYPE_PROC	"PROC"		/* /proc file system */
#define	MNTTYPE_INODE	"INODE"		/* /inode file system */
#define	MNTTYPE_PC	"pc"		/* IBM PC (MSDOS) file system */
#define	MNTTYPE_SWAP	"swap"		/* swap file system */
#define	MNTTYPE_IGNORE	"ignore"	/* ignore this entry */

#define	MNTOPT_RO	"ro"		/* read only */
#define	MNTOPT_RW	"rw"		/* read/write */
#define	MNTOPT_QUOTA	"quota"		/* quotas */
#define	MNTOPT_NOQUOTA	"noquota"	/* no quotas */
#define	MNTOPT_SOFT	"soft"		/* soft mount */
#define	MNTOPT_HARD	"hard"		/* hard mount */
#define	MNTOPT_SPONGY	"spongy"	/* spongy mount */
#define	MNTOPT_NOSUID	"nosuid"	/* no set uid allowed */
#define	MNTOPT_NOAUTO	"noauto"	/* hide entry from mount -a */
#define	MNTOPT_INTR	"intr"		/* allow interrupts on hard mount */
#define MNTOPT_NOCHK	"nochk"		/* no checksum */
#define MNTOPT_CKSUM	"cksum"		/* UDP checksum for this mount */
#define MNTOPT_NOAC	"noac"		/* do not cache NFS file attributes */
#define	MNTOPT_CRAY	"cray"		/* No XDR's necessary between crays */
#define MNTOPT_NOCTO	"nocto"		/* No close to open consistency */
#define MNTOPT_BG       "bg"		/* background */
#define MNTOPT_PORT	"port"		/* port number specified */
#define MNTOPT_RSIZE	"rsize"		/* read buffer size */
#define MNTOPT_TIMEO	"timeo"		/* time out */
#define MNTOPT_RETRAN	"retrans"	/* number of retransmissions */
#define MNTOPT_WSIZE	"wsize"		/* write buffer size */
#define MNTOPT_MIRROR	"mirror"	/* mirror */
#define MNTOPT_FSCKOPT	"fsckopt"	/* gencat's fsck option */
#define MNTOPT_NOLOCK	"nolock"	/* NFS files can't be locked */
#define MNTOPT_NREADAH	"nreadah"	/* Number of NFS rsize readaheads */
#define MNTOPT_KERBEROS	"kerberos"	/* AUTH_KERB required on this mount */

/*
 *	IFMNTHOST gives a non-zero value, if the specified file system
 *	type is native to UNICOS. Otherwise, a zero is returned.
 */
#ifdef	_CRAY2
#define IFMNTHOST(type) (strcmp(type,MNTTYPE_NC2) == 0)
#else	/* CRAY2 */
#define IFMNTHOST(type) (\
	(strcmp(type,MNTTYPE_NC1) == 0)\
	 || (strcmp(type,MNTTYPE_SFS) == 0))
#endif	/* CRAY2 */

struct	mntent {
	char	*mnt_fsname;		/* name of mounted file system */
	char	*mnt_dir;		/* file system path prefix */
	char	*mnt_type;		/* MNTTYPE_* */
	char	*mnt_opts;		/* MNTOPT_* */
	int	mnt_freq;		/* dump frequency, in days */
	int	mnt_passno;		/* pass number on parallel fsck */
};

/* node of the linked list */
struct tabmntent {
        struct mntent *ment;
        struct tabmntent *next;
};

/* general information about the kernel mount table */
struct kmntinfo {
	int	nbent;			/* number of filled entries */
	long	lastchge;		/* last change in the mount table */
};

/*
 *	ismounted() return values.
 */
#define	ISMNT_ERROR		-1	/* unable to determine mount state */
#define	ISMNT_NOTMOUNTED	 0	/* logical device not mounted */
#define	ISMNT_MOUNTEDLOCAL	 1	/* mounted on local machine */
#define	ISMNT_MOUNTEDREMOTE	 2	/* mounted on another machine */
#define	ISMNT_OPENERROR		 3	/* Unable to open the block special */
#define	ISMNT_NOTSFSCAPABLE	 4	/* issfscapable() returns False	    */
#define	ISMNT_NOSFSARBITER	 5	/* Unable to access the SFS Arbiter */

#include <sys/cdefs.h>
#include <fcntl.h>
#include <sys/file.h>

__BEGIN_DECLS
extern struct mntent *getmntent __((FILE *_Mnttabp));
extern char *hasmntopt __((struct mntent *_Mnt, char *_Opt));
extern FILE *setmntent __((char *_Fname));
extern int endmntent __((FILE *_Mnttabp));
extern int ismounted __((char *_Special));
extern struct mntent *dupmntent __((struct mntent *_Mnt));
extern void freemntent __((struct mntent *_Mnt));
extern void freemntlist __((struct tabmntent *_Tabmnt));
extern struct mntent *findmntentry __((struct tabmntent **_Entlist,
	struct mntent *_Mnt, int Flag, int Upd));
extern int listmntent __((struct tabmntent **_Entlist, 
	char *_Fname, char *_Fscomp1, int (*_Fonc1)())); 
extern struct kmntinfo *getmntinfo __((char *_Fname));
__END_DECLS

#endif /* !_MNTENT_H */
